[mapguide-commits] r4748 - sandbox/adsk/2.2gp/Server/src/Gws/GwsCommon/inc

svn_mapguide at osgeo.org svn_mapguide at osgeo.org
Wed Apr 7 12:58:35 EDT 2010


Author: brucedechant
Date: 2010-04-07 12:58:35 -0400 (Wed, 07 Apr 2010)
New Revision: 4748

Modified:
   sandbox/adsk/2.2gp/Server/src/Gws/GwsCommon/inc/GwsThreads.h
Log:
Revert change done to GetMessage().

- This internal API signature shouldn't have changed.
- This API is not being used at this time.


Modified: sandbox/adsk/2.2gp/Server/src/Gws/GwsCommon/inc/GwsThreads.h
===================================================================
--- sandbox/adsk/2.2gp/Server/src/Gws/GwsCommon/inc/GwsThreads.h	2010-04-07 16:19:25 UTC (rev 4747)
+++ sandbox/adsk/2.2gp/Server/src/Gws/GwsCommon/inc/GwsThreads.h	2010-04-07 16:58:35 UTC (rev 4748)
@@ -194,8 +194,8 @@
         Post(); // wake up any waiting threads
     }
 
-    //GetErrorMessage doesn't wait unless you tell it to
-    T* GetErrorMessage(bool bWait = false, unsigned long bWaitTimeMS = IGNORE) {
+    //GetMessage doesn't wait unless you tell it to
+    T* GetMessage(bool bWait = false, unsigned long bWaitTimeMS = IGNORE) {
         if(bWait)
             GWSSemaphore::Wait(bWaitTimeMS); // wait for something to show up
         Lock();



More information about the mapguide-commits mailing list